==> nextcloud-22.2.4.tgz: nextcloud/lib/l10n/vi.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Không thể ghi vào thư mục \"config\"!",
    "See %s" : "Xem %s",
    "Email verification" : "Xác thực email",
    "Click the following button to confirm your email." : "Nhấn nút sau để xác nhận email của bạn.",
    "Click the following link to confirm your email." : "Nhấn liên kết sau để xác nhận email của bạn.",
    "Confirm your email" : "Xác nhận email của bạn",
    "Other activities" : "Hoạt động khác",
    "%1$s and %2$s" : "%1$s và %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s và %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s và %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s và %5$s",
    "Education Edition" : "Bản Giáo dục",
    "Enterprise bundle" : "Gói doanh nghiệp",
    "The library %s is not available." : "Thư viện %s không có sẵn.",
    "The following platforms are supported: %s" : "Các nền tảng sau được hỗ trợ: %s",
    "Server version %s or higher is required." : "Yêu cầu máy chủ phiên bản %s hoặc cao hơn.",
    "Server version %s or lower is required." : "Yêu cầu máy chủ phiên bản %s hoặc thấp hơn.",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "today" : "hôm nay",
    "yesterday" : "hôm qua",
    "last month" : "tháng trước",
    "_%n month ago_::_%n months ago_" : ["%n tháng trước"],
    "last year" : "năm trước",
    "_%n hour ago_::_%n hours ago_" : ["%n giờ trước"],
    "_%n minute ago_::_%n minutes ago_" : ["%n phút trước"],
    "seconds ago" : "vài giây trước",
    "__language_name__" : "Tiếng Việt",
    "Help" : "Giúp đỡ",
    "Apps" : "Ứng dụng",
    "Settings" : "Thiết lập",
    "Log out" : "Đăng xuất",
    "Users" : "Người dùng",
    "Unknown user" : "Người dùng không tồn tại",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Hãy xóa thiết lập open_basedir tại tập tin cấu hình php.ini hoặc chuyển sang dùng PHP 64-bit.",
    "Open »%s«" : "Mở »%s«",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Could not find category \"%s\"" : "không thể tìm thấy mục \"%s\"",
    "Sunday" : "Chủ nhật",
    "Monday" : "Thứ 2",
    "Tuesday" : "Thứ 3",
    "Wednesday" : "Thứ 4",
    "Thursday" : "Thứ 5",
    "Friday" : "Thứ ",
    "Saturday" : "Thứ 7",
    "Sun." : "Chủ nhật",
    "Mon." : "Thứ hai",
    "Tue." : "Thứ ba",
    "Wed." : "Thứ tư",
    "Thu." : "Thứ năm",
    "Fri." : "Thứ sáu",
    "Sat." : "Thứ bảy",
    "January" : "Tháng 1",
    "February" : "Tháng 2",
    "March" : "Tháng 3",
    "April" : "Tháng 4",
    "May" : "Tháng 5",
    "June" : "Tháng 6",
    "July" : "Tháng 7",
    "August" : "Tháng 8",
    "September" : "Tháng 9",
    "October" : "Tháng 10",
    "November" : "Tháng 11",
    "December" : "Tháng 12",
    "Jan." : "Tháng 1",
    "Feb." : "Tháng 2",
    "Mar." : "Tháng 3",
    "Apr." : "Tháng 4",
    "May." : "Tháng 5",
    "Jun." : "Tháng 6",
    "Jul." : "Tháng 7",
    "Aug." : "Tháng 8",
    "Sep." : "Tháng 9",
    "Oct." : "Tháng 10",
    "Nov." : "Tháng 11",
    "Dec." : "Tháng 12",
    "User disabled" : "Vô hiệu hóa sử dụng",
    "a safe home for all your data" : "Một ngôi nhà an toàn cho toàn bộ dữ liệu của bạn",
    "Application is not enabled" : "Ứng dụng không được BẬT",
    "Authentication error" : "Lỗi xác thực",
    "Token expired. Please reload page." : "Mã Token đã hết hạn. Hãy tải lại trang.",
    "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.8.tgz: nextcloud/lib/l10n/vi.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Không thể ghi vào thư mục \"config\"!",
    "See %s" : "Xem %s",
    "Email verification" : "Xác thực email",
    "Click the following button to confirm your email." : "Nhấn nút sau để xác nhận email của bạn.",
    "Click the following link to confirm your email." : "Nhấn liên kết sau để xác nhận email của bạn.",
    "Confirm your email" : "Xác nhận email của bạn",
    "Other activities" : "Hoạt động khác",
    "%1$s and %2$s" : "%1$s và %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s và %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s và %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s và %5$s",
    "Education Edition" : "Bản Giáo dục",
    "Enterprise bundle" : "Gói doanh nghiệp",
    "The library %s is not available." : "Thư viện %s không có sẵn.",
    "The following platforms are supported: %s" : "Các nền tảng sau được hỗ trợ: %s",
    "Server version %s or higher is required." : "Yêu cầu máy chủ phiên bản %s hoặc cao hơn.",
    "Server version %s or lower is required." : "Yêu cầu máy chủ phiên bản %s hoặc thấp hơn.",
    "Unknown filetype" : "Không biết kiểu tập tin",
    "Invalid image" : "Hình ảnh không hợp lệ",
    "today" : "hôm nay",
    "yesterday" : "hôm qua",
    "last month" : "tháng trước",
    "_%n month ago_::_%n months ago_" : ["%n tháng trước"],
    "next year" : "năm tới",
    "last year" : "năm trước",
    "_%n hour ago_::_%n hours ago_" : ["%n giờ trước"],
    "_%n minute ago_::_%n minutes ago_" : ["%n phút trước"],
    "seconds ago" : "vài giây trước",
    "File already exists" : "Tệp đã tồn tại",
    "Templates" : "‎Mẫu‎",
    "__language_name__" : "Tiếng Việt",
    "Help" : "Giúp đỡ",
    "Apps" : "Ứng dụng",
    "Settings" : "Thiết lập",
    "Log out" : "Đăng xuất",
    "Users" : "Người dùng",
    "Email" : "Thư điện tử",
    "Phone" : "Điện thoại",
    "Twitter" : "Twitter",
    "Website" : "Website",
    "Address" : "Địa chỉ",
    "About" : "Giới thiệu",
    "Full name" : "Tên đầy đủ",
    "Unknown user" : "Người dùng không tồn tại",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Hãy xóa thiết lập open_basedir tại tập tin cấu hình php.ini hoặc chuyển sang dùng PHP 64-bit.",
    "Open »%s«" : "Mở »%s«",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
    "Could not find category \"%s\"" : "không thể tìm thấy mục \"%s\"",
    "Sunday" : "Chủ nhật",
    "Monday" : "Thứ 2",
    "Tuesday" : "Thứ 3",
    "Wednesday" : "Thứ 4",
    "Thursday" : "Thứ 5",
    "Friday" : "Thứ ",
    "Saturday" : "Thứ 7",
    "Sun." : "Chủ nhật",
    "Mon." : "Thứ hai",
    "Tue." : "Thứ ba",
    "Wed." : "Thứ tư",
    "Thu." : "Thứ năm",
    "Fri." : "Thứ sáu",
    "Sat." : "Thứ bảy",
    "January" : "Tháng 1",
    "February" : "Tháng 2",
    "March" : "Tháng 3",
    "April" : "Tháng 4",
    "May" : "Tháng 5",
    "June" : "Tháng 6",
    "July" : "Tháng 7",
    "August" : "Tháng 8",
    "September" : "Tháng 9",
    "October" : "Tháng 10",
    "November" : "Tháng 11",
    "December" : "Tháng 12",
    "Jan." : "Tháng 1",
    "Feb." : "Tháng 2",
    "Mar." : "Tháng 3",
    "Apr." : "Tháng 4",
    "May." : "Tháng 5",
    "Jun." : "Tháng 6",
    "Jul." : "Tháng 7",
    "Aug." : "Tháng 8",
    "Sep." : "Tháng 9",
    "Oct." : "Tháng 10",
    "Nov." : "Tháng 11",
    "Dec." : "Tháng 12",
    "User disabled" : "Vô hiệu hóa sử dụng",
    "a safe home for all your data" : "Một ngôi nhà an toàn cho toàn bộ dữ liệu của bạn",
    "Application is not enabled" : "Ứng dụng không được BẬT",
    "Authentication error" : "Lỗi xác thực",
    "Token expired. Please reload page." : "Mã Token đã hết hạn. Hãy tải lại trang.",
    "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng"
},
"nplurals=1; plural=0;");
